@@ -600,13 +600,16 @@ class Album:
         for photo in self.photos():
             exported_photos.extend(
                 photo.export(
-                    export_path=export_path, original=original, overwrite=overwrite, timeout=timeout
+                    export_path=export_path,
+                    original=original,
+                    overwrite=overwrite,
+                    timeout=timeout,
                 )
             )
         return exported_photos
 
     def remove_by_id(self, photo_ids):
-        """Remove photos from album.
+        """Remove photos from album. 
             Note: Photos does not provide a way to remove photos from an album via AppleScript.
             This method actually creates a new Album with the same name as the original album and
             copies all photos from original album with exception of those to remove to the new album
@@ -633,6 +636,7 @@ class Album:
         photoslib.delete_album(self)
         new_album.name = name
         self.id = new_album.id
+        self._uuid = new_album.uuid
         return new_album
 
     def remove(self, photos):
@@ -665,10 +669,10 @@ class Folder:
                 id_ = f"{uuid}{UUID_SUFFIX_FOLDER}"
             else:
                 uuid = uuid.split("/")[0]
-        
+
         valid_folder = run_script("_folder_exists", id_)
         if valid_folder:
-            self.id = id_ 
+            self.id = id_
             self._uuid = uuid
         else:
             raise ValueError(f"Invalid folder id: {uuid}")
@@ -800,10 +804,18 @@ class Folder:
 
 class Photo:
     def __init__(self, uuid):
+        id_ = uuid
+        # check to see if we need to add UUID suffix
+        if float(PhotosLibrary().version) >= 5.0:
+            if len(uuid.split("/")) == 1:
+                # osxphotos style UUID without the suffix
+                id_ = f"{uuid}{UUID_SUFFIX_FOLDER}"
+            else:
+                uuid = uuid.split("/")[0]
         valid = run_script("_photo_exists", uuid)
         if valid:
-            self.id = uuid
-            self._uuid = uuid.split("/")[0]
+            self.id = id_
+            self._uuid = uuid
         else:
             raise ValueError(f"Invalid photo id: {uuid}")
 
@@ -816,7 +828,7 @@ class Photo:
     def name(self):
         """ name of photo """
         name = run_script("_photo_name", self.id)
-        return name if name != kMissingValue else None
+        return name if name not in [kMissingValue, ""] else None
 
     @name.setter
     def name(self, name):
@@ -870,7 +882,7 @@ class Photo:
     @favorite.setter
     def favorite(self, favorite):
         """ set favorite status (boolean) """
-        favorite = True if favorite else False
+        favorite = bool(favorite)
         return run_script("_photo_set_favorite", self.id, favorite)
 
     @property
@@ -886,7 +898,8 @@ class Photo:
     @property
     def altitude(self):
         """ GPS altitude of photo in meters """
-        return run_script("_photo_altitude", self.id)
+        altitude = run_script("_photo_altitude", self.id)
+        return altitude if altitude != kMissingValue else None
 
     @property
     def location(self):
@@ -927,6 +940,15 @@ class Photo:
         """ date of photo as timezone-naive datetime.datetime object """
         return run_script("_photo_date", self.id)
 
+    @date.setter
+    def date(self, date):
+        """ Set date of photo as timezone-naive datetime.datetime object
+        
+        Args:
+            date: timezone-naive datetime.datetime object
+        """
+        return run_script("_photo_set_date", self.id, date)
+
     @property
     def filename(self):
         """ filename of photo """
